==============================
Blazar Configuration Reference
==============================

Configuration
-------------

Reference
^^^^^^^^^

.. toctree::

   blazar-conf.rst
   nova-conf.rst

.. # NOTE(priteau): Keep sample files for HTML only.
   # Sample files are too large and cause TeX memory issues.
   # See bug https://bugs.launchpad.net/blazar/+bug/1885250

.. only:: html

   Sample Files
   ^^^^^^^^^^^^

   .. toctree::

      samples/blazar-conf.rst

Policy
------

Reference
^^^^^^^^^

.. toctree::

   blazar-policy.rst

.. # NOTE(priteau): Keep sample files for HTML only.
   # Sample files are too large and cause TeX memory issues.
   # See bug https://bugs.launchpad.net/blazar/+bug/1885250

.. only:: html

   Sample Files
   ^^^^^^^^^^^^

   .. toctree::

      samples/blazar-policy.rst
